@@ -158,6 +158,10 @@ class Two(One):
     """Two."""
 
 
+class Three:
+    __init__ = Two.__init__
+
+
 def fn_with_long_sig(
     this,
     *,
@@ -169,7 +173,7 @@ def fn_with_long_sig(
     signature,
     many,
     keyword,
-    arguments
+    arguments,
 ):
     """A function with a long signature."""
 
